@@ -10,14 +10,6 @@
 
 static const char* FILE_NAME = "Net/SSLeay.c";
 
-int32_t SPVM__Net__SSLeay___print_version_text(SPVM_ENV* env, SPVM_VALUE* stack) {
-  
-  char *version = OPENSSL_VERSION_TEXT;
-  fprintf(stderr, "OpenSSL version: %s\n", version);
-    
-  return 0;
-}
-
 // Class Methods
 int32_t SPVM__Net__SSLeay__new(SPVM_ENV* env, SPVM_VALUE* stack) {
   
