@@ -1,6 +1,6 @@
 package SPVM::Net::SSLeay;
 
-our $VERSION = "0.016";
+our $VERSION = "0.017";
 
 1;
 
@@ -16,18 +16,58 @@ B<Warnings:>
 
 B<The tests haven't been written yet. The features may be changed without notice.> 
 
+=head1 Details
+
+=head2 Requirement
+
+OpenSSL 1.1.1
+
 =head1 Modules
 
 =over 2
 
 =item * L<Net::SSLeay|SPVM::Net::SSLeay>
 
+=item * L<Net::SSLeay::ASN1_ENUMERATED|SPVM::Net::SSLeay::ASN1_ENUMERATED>
+
+=item * L<Net::SSLeay::ASN1_GENERALIZEDTIME|SPVM::Net::SSLeay::ASN1_GENERALIZEDTIME>
+
+=item * L<Net::SSLeay::ASN1_INTEGER|SPVM::Net::SSLeay::ASN1_INTEGER>
+
 =item * L<Net::SSLeay::ASN1_OBJECT|SPVM::Net::SSLeay::ASN1_OBJECT>
 
+=item * L<Net::SSLeay::ASN1_TIME|SPVM::Net::SSLeay::ASN1_TIME>
+
 =item * L<Net::SSLeay::BIO|SPVM::Net::SSLeay::BIO>
 
+=item * L<Net::SSLeay::Callback::AlpnSelect|SPVM::Net::SSLeay::Callback::AlpnSelect>
+
+=item * L<Net::SSLeay::Callback::Msg|SPVM::Net::SSLeay::Callback::Msg>
+
+=item * L<Net::SSLeay::Callback::NewSession|SPVM::Net::SSLeay::Callback::NewSession>
+
+=item * L<Net::SSLeay::Callback::NextProtosAdvertised|SPVM::Net::SSLeay::Callback::NextProtosAdvertised>
+
+=item * L<Net::SSLeay::Callback::NextProtoSelect|SPVM::Net::SSLeay::Callback::NextProtoSelect>
+
+=item * L<Net::SSLeay::Callback::PemPasswd|SPVM::Net::SSLeay::Callback::PemPasswd>
+
+=item * L<Net::SSLeay::Callback::PskClient|SPVM::Net::SSLeay::Callback::PskClient>
+
+=item * L<Net::SSLeay::Callback::PskServer|SPVM::Net::SSLeay::Callback::PskServer>
+
+=item * L<Net::SSLeay::Callback::RemoveSession|SPVM::Net::SSLeay::Callback::RemoveSession>
+
+=item * L<Net::SSLeay::Callback::TlsextServername|SPVM::Net::SSLeay::Callback::TlsextServername>
+
+=item * L<Net::SSLeay::Callback::TlsextStatus|SPVM::Net::SSLeay::Callback::TlsextStatus>
+
+=item * L<Net::SSLeay::Callback::TlsextTicketKey|SPVM::Net::SSLeay::Callback::TlsextTicketKey>
+
 =item * L<Net::SSLeay::Constant|SPVM::Net::SSLeay::Constant>
 
+=item * L<Net::SSLeay::DER|SPVM::Net::SSLeay::DER>
+
 =item * L<Net::SSLeay::DH|SPVM::Net::SSLeay::DH>
 
 =item * L<Net::SSLeay::EC_KEY|SPVM::Net::SSLeay::EC_KEY>
@@ -38,16 +78,40 @@ B<The tests haven't been written yet. The features may be changed without notice
 
 =item * L<Net::SSLeay::EVP|SPVM::Net::SSLeay::EVP>
 
+=item * L<Net::SSLeay::EVP_CIPHER_CTX|SPVM::Net::SSLeay::EVP_CIPHER_CTX>
+
 =item * L<Net::SSLeay::EVP_MD|SPVM::Net::SSLeay::EVP_MD>
 
 =item * L<Net::SSLeay::EVP_PKEY|SPVM::Net::SSLeay::EVP_PKEY>
 
+=item * L<Net::SSLeay::HMAC_CTX|SPVM::Net::SSLeay::HMAC_CTX>
+
 =item * L<Net::SSLeay::OBJ|SPVM::Net::SSLeay::OBJ>
 
+=item * L<Net::SSLeay::OCSP|SPVM::Net::SSLeay::OCSP>
+
+=item * L<Net::SSLeay::OCSP_BASICRESP|SPVM::Net::SSLeay::OCSP_BASICRESP>
+
+=item * L<Net::SSLeay::OCSP_CERTID|SPVM::Net::SSLeay::OCSP_CERTID>
+
+=item * L<Net::SSLeay::OCSP_ONEREQ|SPVM::Net::SSLeay::OCSP_ONEREQ>
+
+=item * L<Net::SSLeay::OCSP_REQUEST|SPVM::Net::SSLeay::OCSP_REQUEST>
+
+=item * L<Net::SSLeay::OCSP_RESPONSE|SPVM::Net::SSLeay::OCSP_RESPONSE>
+
+=item * L<Net::SSLeay::OCSP_SINGLERESP|SPVM::Net::SSLeay::OCSP_SINGLERESP>
+
 =item * L<Net::SSLeay::OPENSSL|SPVM::Net::SSLeay::OPENSSL>
 
+=item * L<Net::SSLeay::OPENSSL_INIT|SPVM::Net::SSLeay::OPENSSL_INIT>
+
+=item * L<Net::SSLeay::OPENSSL_INIT_SETTINGS|SPVM::Net::SSLeay::OPENSSL_INIT_SETTINGS>
+
 =item * L<Net::SSLeay::PEM|SPVM::Net::SSLeay::PEM>
 
+=item * L<Net::SSLeay::PKCS12|SPVM::Net::SSLeay::PKCS12>
+
 =item * L<Net::SSLeay::RAND|SPVM::Net::SSLeay::RAND>
 
 =item * L<Net::SSLeay::SSL_CIPHER|SPVM::Net::SSLeay::SSL_CIPHER>
@@ -390,16 +454,28 @@ C<method set_msg_callback : void ($cb : L<Net::SSLeay::Callback::Msg|SPVM::Net::
 
 Calls native L<SSL_set_msg_callback|https://docs.openssl.org/1.1.1/man3/SSL_CTX_set_msg_callback> function given $cb, $arg, and returns its return value.
 
+=head2 P_dump_peer_certificate
+
+C<static method P_dump_peer_certificate : string ();>
+
+Returns the same output of Perl's L<Net::SSLeay#dump_peer_certificate|https://metacpan.org/dist/Net-SSLeay/view/lib/Net/SSLeay.pod#Convenience-routines> function.
+
 =head2 DESTROY
 
 C<method DESTROY : void ();>
 
 Frees native L<SSL|https://docs.openssl.org/1.0.2/man3/SSL_free> object by calling native L<SSL_free|https://docs.openssl.org/1.0.2/man3/SSL_free> function if C<no_free> flag of the instance is not a true value.
 
-=head2 Config Builder
+=head1 Config Builder
 
 L<SPVM::Net::SSLeay::ConfigBuilder>
 
+=head1 FAQ
+
+=head2 Is LibreSSL supported?
+
+Yes.
+
 =head1 Porting
 
 This class is a Perl's L<Net::SSLeay> porting to L<SPVM>.
